@@ -416,9 +416,9 @@ def aws_create_report(options):  # noqa: C901
         monthly_files = []
         fake = Faker()
         num_gens = len(generators)
-        LOG.info(f"Producing data for {num_gens} generators for {month.get('name')}.")
-        count = 0
-        for generator in generators:
+        ten_percent = int(num_gens * 0.1) if num_gens > 50 else 5
+        LOG.info(f"Producing data for {num_gens} generators for {month.get('start').strftime('%Y-%m')}.")
+        for count, generator in enumerate(generators):
             generator_cls = generator.get("generator")
             attributes = generator.get("attributes")
             gen_start_date = month.get("start")
@@ -451,8 +451,7 @@ def aws_create_report(options):  # noqa: C901
                         monthly_files.append(month_output_file)
                         data.clear()
 
-            count += 1
-            if count % 1000 == 0:
+            if count % ten_percent == 0:
                 LOG.info(f"Done with {count} of {num_gens} generators.")
 
         if file_number != 0:
@@ -528,9 +527,9 @@ def azure_create_report(options):  # noqa: C901
         data = []
         monthly_files = []
         num_gens = len(generators)
-        LOG.info(f"Producing data for {num_gens} generators for {month.get('name')}.")
-        count = 0
-        for generator in generators:
+        ten_percent = int(num_gens * 0.1) if num_gens > 50 else 5
+        LOG.info(f"Producing data for {num_gens} generators for {month.get('start').strftime('%Y-%m')}.")
+        for count, generator in enumerate(generators):
             generator_cls = generator.get("generator")
             attributes = generator.get("attributes", {})
             gen_start_date = month.get("start")
@@ -551,8 +550,7 @@ def azure_create_report(options):  # noqa: C901
             data += gen.generate_data()
             meter_cache = gen.get_meter_cache()
 
-            count += 1
-            if count % 1000 == 0:
+            if count % ten_percent == 0:
                 LOG.info(f"Done with {count} of {num_gens} generators.")
 
         local_path, output_file_name = _generate_azure_filename()
@@ -721,9 +719,9 @@ def gcp_create_report(options):  # noqa: C901
     data = {}
     for project in projects:
         num_gens = len(generators)
+        ten_percent = int(num_gens * 0.1) if num_gens > 50 else 5
         LOG.info(f"Producing data for {num_gens} generators for {'INSERT SOMETHING FOR GCP'}.")
-        count = 0
-        for generator in generators:
+        for count, generator in enumerate(generators):
             attributes = generator.get("attributes", {})
             if attributes:
                 start_date = attributes.get("start_date")
@@ -739,7 +737,7 @@ def gcp_create_report(options):  # noqa: C901
                     data[key] = item
 
             count += 1
-            if count % 1000 == 0:
+            if count % ten_percent == 0:
                 LOG.info(f"Done with {count} of {num_gens} generators.")
 
     monthly_files = []
